==> libcec_1.6.2.orig.tar.gz: libcec-1.6.2/src/lib/devices/CECRecordingDevice.cpp <==
/*
 * This file is part of the libCEC(R) library.
 *
 * libCEC(R) is Copyright (C) 2011-2012 Pulse-Eight Limited.  All rights reserved.
 * libCEC(R) is an original work, containing original code.
 *
 * libCEC(R) is a trademark of Pulse-Eight Limited.
 *
 * This program is dual-licensed; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *
 * Alternatively, you can license this library under a commercial license,
 * please contact Pulse-Eight Licensing for more information.
 *
 * For more information contact:
 * Pulse-Eight Licensing       <license@pulse-eight.com>
 *     http://www.pulse-eight.com/
 *     http://www.pulse-eight.net/
 */

#include "CECRecordingDevice.h"

using namespace CEC;

CCECRecordingDevice::CCECRecordingDevice(CCECProcessor *processor, cec_logical_address address, uint16_t iPhysicalAddress /* = CEC_INVALID_PHYSICAL_ADDRESS */) :
    CCECBusDevice(processor, address, iPhysicalAddress),
    m_playbackDevice(processor, address, iPhysicalAddress),
    m_tuner(processor, address, iPhysicalAddress)
{
  m_type = CEC_DEVICE_TYPE_RECORDING_DEVICE;
}

cec_deck_info CCECRecordingDevice::GetDeckStatus(void)
{
  return m_playbackDevice.GetDeckStatus();
}

cec_deck_control_mode CCECRecordingDevice::GetDeckControlMode(void)
{
  return m_playbackDevice.GetDeckControlMode();
}

void CCECRecordingDevice::SetDeckStatus(cec_deck_info deckStatus)
{
  m_playbackDevice.SetDeckStatus(deckStatus);
}

void CCECRecordingDevice::SetDeckControlMode(cec_deck_control_mode mode)
{
  m_playbackDevice.SetDeckControlMode(mode);
}

bool CCECRecordingDevice::TransmitDeckStatus(cec_logical_address dest)
{
  return m_playbackDevice.TransmitDeckStatus(dest);
}

==> libcec-1.7.1.tar.gz: libcec-1.7.1/src/lib/devices/CECRecordingDevice.cpp <==
/*
 * This file is part of the libCEC(R) library.
 *
 * libCEC(R) is Copyright (C) 2011-2012 Pulse-Eight Limited.  All rights reserved.
 * libCEC(R) is an original work, containing original code.
 *
 * libCEC(R) is a trademark of Pulse-Eight Limited.
 *
 * This program is dual-licensed; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *
 * Alternatively, you can license this library under a commercial license,
 * please contact Pulse-Eight Licensing for more information.
 *
 * For more information contact:
 * Pulse-Eight Licensing       <license@pulse-eight.com>
 *     http://www.pulse-eight.com/
 *     http://www.pulse-eight.net/
 */

#include "CECRecordingDevice.h"

using namespace CEC;
using namespace PLATFORM;

CCECRecordingDevice::CCECRecordingDevice(CCECProcessor *processor, cec_logical_address address, uint16_t iPhysicalAddress /* = CEC_INVALID_PHYSICAL_ADDRESS */) :
    CCECPlaybackDevice(processor, address, iPhysicalAddress),
    m_tuner(processor, address, iPhysicalAddress)
{
  m_type = CEC_DEVICE_TYPE_RECORDING_DEVICE;
}

void CCECRecordingDevice::ResetDeviceStatus(void)
{
  CLockObject lock(m_mutex);
  m_tuner.ResetDeviceStatus();
  CCECPlaybackDevice::ResetDeviceStatus();
}
